==> org.eclipse.sirius.diagram.ui.source_4.1.5.201705040741.jar: org/eclipse/sirius/diagram/ui/tools/internal/editor/tabbar/actions/PasteFormatMenuManager.java <==
/*******************************************************************************
 * Copyright (c) 2016 THALES GLOBAL SERVICES and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.ui.tools.internal.editor.tabbar.actions;

import org.eclipse.gmf.runtime.common.ui.action.ActionMenuManager;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.sirius.diagram.ui.provider.DiagramUIPlugin;
import org.eclipse.sirius.diagram.ui.provider.Messages;
import org.eclipse.sirius.diagram.ui.tools.api.image.DiagramImagesPath;
import org.eclipse.sirius.diagram.ui.tools.api.ui.actions.ActionIds;

/**
 * The paste format menu manager. It contains all paste format related actions
 * (format, layout and style).
 * 
 * @author <a href="mailto:laurent.redor@obeo.fr">Laurent Redor</a>
 */
public class PasteFormatMenuManager extends ActionMenuManager {

    /**
     * The paste format menu action containing the UI for the paste format menu
     * manager
     */
    private static class PasteFormatMenuAction extends Action {
        public PasteFormatMenuAction() {
            setText(Messages.PasteFormatAction_text);
            setToolTipText(Messages.PasteFormatAction_toolTipText);
            ImageDescriptor imageDesc = DiagramUIPlugin.Implementation.getBundledImageDescriptor(DiagramImagesPath.PASTE_FORMAT_ICON);
            setImageDescriptor(imageDesc);
            setHoverImageDescriptor(imageDesc);
        }
    }

    /**
     * Creates a new instance of the distribute menu manager.
     */
    public PasteFormatMenuManager() {
        super(ActionIds.MENU_PASTE_FORMAT, new PasteFormatMenuAction(), true);
    }
}

==> org.eclipse.sirius.diagram.ui.source_5.0.0.201706130939.jar: org/eclipse/sirius/diagram/ui/tools/internal/editor/tabbar/actions/PasteFormatMenuManager.java <==
/*******************************************************************************
 * Copyright (c) 2016 THALES GLOBAL SERVICES and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.ui.tools.internal.editor.tabbar.actions;

import org.eclipse.gmf.runtime.common.ui.action.ActionMenuManager;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.sirius.diagram.ui.provider.DiagramUIPlugin;
import org.eclipse.sirius.diagram.ui.provider.Messages;
import org.eclipse.sirius.diagram.ui.tools.api.image.DiagramImagesPath;
import org.eclipse.sirius.diagram.ui.tools.api.ui.actions.ActionIds;

/**
 * The paste format menu manager. It contains all paste format related actions
 * (format, layout and style).
 * 
 * @author <a href="mailto:laurent.redor@obeo.fr">Laurent Redor</a>
 */
public class PasteFormatMenuManager extends ActionMenuManager {

    /**
     * The paste format menu action containing the UI for the paste format menu
     * manager
     */
    private static class PasteFormatMenuAction extends Action {
        PasteFormatMenuAction() {
            setText(Messages.PasteFormatAction_text);
            setToolTipText(Messages.PasteFormatAction_toolTipText);
            ImageDescriptor imageDesc = DiagramUIPlugin.Implementation.getBundledImageDescriptor(DiagramImagesPath.PASTE_FORMAT_ICON);
            setImageDescriptor(imageDesc);
            setHoverImageDescriptor(imageDesc);
        }
    }

    /**
     * Creates a new instance of the distribute menu manager.
     */
    public PasteFormatMenuManager() {
        super(ActionIds.MENU_PASTE_FORMAT, new PasteFormatMenuAction(), true);
    }
}
